==> lazylinop-1.6.0a3-py3-none-any.whl: lazylinop/basicops/cat.py <==
from lazylinop import islazylinop, aslazylinop


def hstack(ops):
    """
    Concatenates linear operators horizontally.

    Args:
        ops: (``tuple`` of compatible linear operators)
            For any pair ``i, j < len(ops)``, ``ops[i].shape[0] ==
            ops[i].shape[0]``.

    Returns:
        A concatenation :class:`LazyLinOp`.

    Example:
        >>> from lazylinop import hstack, ones, islazylinop
        >>> import numpy as np
        >>> A = np.ones((10, 10))
        >>> B = ones((10, 2))
        >>> lcat = hstack((A, B))
        >>> islazylinop(lcat)
        True
        >>> np.allclose(lcat.toarray(), np.hstack((A, B.toarray())))
        True

    .. seealso::

        :func:`vstack`
        `numpy.hstack
        <https://numpy.org/doc/stable/reference/generated/numpy.hstack.html>`_
    """
    lop = ops[0]
    if not islazylinop(lop):
        lop = aslazylinop(ops[0])
    return lop.concatenate(*ops[1:], axis=1)


def vstack(ops):
    """
    Concatenates linear operators horizontally.

    Args:
        ops: (``tuple`` of compatible linear operators)
            For any pair ``i, j < len(ops)``, ``ops[i].shape[1] ==
            ops[i].shape[1]``.

    Returns:
        A concatenation :class:`LazyLinOp`.

    Example:
        >>> from lazylinop import vstack, ones, islazylinop
        >>> import numpy as np
        >>> A = np.ones((10, 10))
        >>> B = ones((2, 10))
        >>> lcat = vstack((A, B))
        >>> islazylinop(lcat)
        True
        >>> np.allclose(lcat.toarray(), np.vstack((A, B.toarray())))
        True

    .. seealso::
        :func:`hstack`
        `numpy.hstack
        <https://numpy.org/doc/stable/reference/generated/numpy.hstack.html>`_

    """
    lop = ops[0]
    if not islazylinop(lop):
        lop = aslazylinop(ops[0])
    return lop.concatenate(*ops[1:], axis=0)

==> lazylinop-1.11.1-py3-none-any.whl: lazylinop/basicops/cat.py <==
from lazylinop import aslazylinop


def hstack(ops):
    """
    Concatenates linear operators horizontally.

    Args:
        ops: (``tuple`` of compatible linear operators)
            For any pair ``i, j < len(ops)``, ``ops[i].shape[0] ==
            ops[i].shape[0]``.

    Returns:
        A concatenation :class:`LazyLinOp`.

    Example:
        >>> import numpy as np
        >>> import lazylinop as lz
        >>> from lazylinop import islazylinop
        >>> A = np.ones((10, 10))
        >>> B = lz.ones((10, 2))
        >>> lcat = lz.hstack((A, B))
        >>> islazylinop(lcat)
        True
        >>> np.allclose(lcat.toarray(), np.hstack((A, B.toarray())))
        True

    .. seealso::

        :func:`vstack`,
        `numpy.hstack,
        <https://numpy.org/doc/stable/reference/generated/numpy.hstack.html>`_
        :func:`.aslazylinop`
    """
    lop = aslazylinop(ops[0])
    return lop.concatenate(*ops[1:], axis=1)


def vstack(ops):
    """
    Concatenates linear operators horizontally.

    Args:
        ops: (``tuple`` of compatible linear operators)
            For any pair ``i, j < len(ops)``, ``ops[i].shape[1] ==
            ops[i].shape[1]``.

    Returns:
        A concatenation :class:`LazyLinOp`.

    Example:
        >>> import numpy as np
        >>> import lazylinop as lz
        >>> from lazylinop import islazylinop
        >>> A = np.ones((10, 10))
        >>> B = lz.ones((2, 10))
        >>> lcat = lz.vstack((A, B))
        >>> islazylinop(lcat)
        True
        >>> np.allclose(lcat.toarray(), np.vstack((A, B.toarray())))
        True

    .. seealso::
        :func:`hstack`
        `numpy.vstack
        <https://numpy.org/doc/stable/reference/generated/numpy.vstack.html>`_
        :func:`.aslazylinop`

    """
    lop = aslazylinop(ops[0])
    return lop.concatenate(*ops[1:], axis=0)
